Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(46)

Unified Diff: components/url_pattern_index/url_pattern_index.cc

Issue 2716583003: Rename Origin.unique() to opaque().
Patch Set: Update new uses post-rebase Created 3 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/url_pattern_index/url_pattern_index.cc
diff --git a/components/url_pattern_index/url_pattern_index.cc b/components/url_pattern_index/url_pattern_index.cc
index 38d75e811eec7f1484a89816e0a77ef9242c10ee..91a7e55a7b57436a75626b8284710556a60fc421 100644
--- a/components/url_pattern_index/url_pattern_index.cc
+++ b/components/url_pattern_index/url_pattern_index.cc
@@ -441,7 +441,7 @@ size_t GetLongestMatchingSubdomain(const url::Origin& origin,
}
// Otherwise look for each subdomain of the |origin| using binary search.
- DCHECK(!origin.unique());
+ DCHECK(!origin.opaque());
base::StringPiece canonicalized_host(origin.host());
if (canonicalized_host.empty())
return 0;
@@ -497,8 +497,8 @@ bool DoesOriginMatchDomainList(const url::Origin& origin,
if (disable_generic_rules && is_generic)
return false;
- // Unique |origin| matches lists of exception domains only.
- if (origin.unique())
+ // Opaque |origin| matches lists of exception domains only.
+ if (origin.opaque())
return is_generic;
size_t longest_matching_included_domain_length = 1;
« no previous file with comments | « components/subresource_filter/core/common/first_party_origin.cc ('k') | components/url_pattern_index/url_rule_test_support.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698